@@ -2,14 +2,13 @@ package KiokuDB::Serializer;
 BEGIN {
   $KiokuDB::Serializer::AUTHORITY = 'cpan:NUFFIN';
 }
-{
-  $KiokuDB::Serializer::VERSION = '0.56';
-}
+$KiokuDB::Serializer::VERSION = '0.57';
 use Moose::Role;
 # ABSTRACT: Standalone serializer object
 
 use Carp qw(croak);
 
+use Class::Load ();
 use Moose::Util::TypeConstraints;
 
 use namespace::clean -except => 'meta';
@@ -28,13 +27,13 @@ my %types = (
 coerce( __PACKAGE__,
     from Str => via {
         my $class = $types{lc($_)} or croak "unknown format: $_";;
-        Class::MOP::load_class($class);
+        Class::Load::load_class($class);
         $class->new;
     },
     from HashRef => via {
         my %args = %$_;
         my $class = $types{lc(delete $args{format})} or croak "unknown format: $args{format}";
-        Class::MOP::load_class($class);
+        Class::Load::load_class($class);
         $class->new(%args);
     },
 );
@@ -45,13 +44,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 KiokuDB::Serializer - Standalone serializer object
 
 =head1 VERSION
 
-version 0.56
+version 0.57
 
 =head1 SYNOPSIS
 
@@ -73,7 +74,7 @@ Yuval Kogman <nothingmuch@woobling.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Yuval Kogman, Infinity Interactive.
+This software is copyright (c) 2014 by Yuval Kogman, Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
